"""
    This file is part of Accountant.

    Accountant is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Accountant is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with Accountant.  If not, see <http://www.gnu.org/licenses/>.
"""
import click

from flask import Flask

from flask_alembic import Alembic
from flask_alembic import alembic_click

from .models import db
from .views import api, cors

# The app
app = Flask(__name__, static_folder=None, template_folder=None)

# Configure it from config.cfg.
app.config.from_pyfile('config.cfg')

app.config['SQLALCHEMY_ECHO'] = app.debug
app.config['SQLALCHEMY_COMMIT_ON_TEARDOWN'] = True
app.config['SQLALCHEMY_TRACK_MODIFICATIONS'] = True

db.init_app(app)

# Database migrations.
alembic = Alembic(app)







# Database initialization.
@alembic_click.command()
def initdb():
    """ Create the database ans stamp it. """
    click.echo("Creating database.")
    db.metadata.create_all(bind=db.engine)
    click.echo("Stamping database.")
    alembic.stamp()
    click.echo("Database created.")


@alembic_click.command()
def dropdb():
    """Clear database schema. USE CAREFULLY!!"""
    click.echo("Clearing database.")
    db.metadata.drop_all(bind=db.engine)
    click.echo("Database cleared.")


api.init_app(app)
cors.init_app(app)
